@@ -56,6 +56,14 @@ impl<'a, I: Interface> Protocol<'a, I> {
     }
 
     pub fn send_packet(&mut self, packet: &Packet) -> Result<(), ProtocolError> {
+        if packet.device_address == self.device_address
+        || packet.device_address == BROADCAST_ADDRESS
+        {
+            self.handle_packet(&packet, true);
+        } else {
+            self.handle_packet(&packet, false);
+        }
+
         match self.interface.try_send_packet(packet) {
             Ok(_) => Ok(()),
             Err(err) => Err(ProtocolError::InterfaceError(err)),
